
0.4.3 (2021-03-16)
------------------

- Fixed crash from new Luigi.
- Fixed crash from new Click.


0.4.2 (2017-03-01)
------------------

- Add a `--port` command line option to select the port the scheduler listen to.


0.4.1 (2017-02-14)
------------------

- Fixed a couple of string Python2/3 bugs.


0.4.0 (2016-08-02)
------------------

- Change default Mako filter to pretty print iterables.
- Add IMPORT_MODULES variable to import modules in the template namespace.


0.3.0 (2016-02-10)
------------------

- All special variable in mariofile are now uppercase.
- Add support for SHELL variable.
